@@ -30,7 +30,9 @@ class CommandType(Enum):
     SetInstanceField = 25
     InvokeGenericStaticMethod = 26
     InvokeGenericMethod = 27
-    CreateGenericClassInstance = 28
-    GetEnumItem = 29
-    GetEnumName = 30
-    GetEnumValue = 31
+    GetEnumItem = 28
+    GetEnumName = 29
+    GetEnumValue = 30
+    AsRef = 31
+    AsOut = 32
+    GetRefValue = 33
