@@ -6,6 +6,7 @@ require_relative '../../core/handler/command_handler/load_library_handler'
 require_relative '../../core/handler/command_handler/invoke_static_method_handler'
 require_relative '../../core/handler/command_handler/get_static_field_handler'
 require_relative '../../core/handler/command_handler/get_instance_field_handler'
+require_relative '../../core/handler/command_handler/set_instance_field_handler'
 require_relative '../../core/handler/command_handler/create_class_instance_handler'
 require_relative '../../core/handler/command_handler/set_static_field_handler'
 require_relative '../../core/handler/command_handler/get_type_handler'
@@ -38,6 +39,7 @@ class Handler < AbstractHandler
     resolve_instance_handler = ResolveInstanceHandler.new
     casting_handler = CastingHandler.new
     get_instance_field_handler = GetInstanceFieldHandler.new
+    set_instance_field_handler = SetInstanceFieldHandler.new
     destruct_reference_handler = DestructReferenceHandler.new
     array_get_item_handler = ArrayGetItemHandler.new
     array_get_size_handler = ArrayGetSizeHandler.new
@@ -57,13 +59,13 @@ class Handler < AbstractHandler
     $handler_dict[CommandType::REFERENCE] = resolve_instance_handler
     $handler_dict[CommandType::CAST] = casting_handler
     $handler_dict[CommandType::GET_INSTANCE_FIELD] = get_instance_field_handler
+    $handler_dict[CommandType::SET_INSTANCE_FIELD] = set_instance_field_handler
     $handler_dict[CommandType::DESTRUCT_REFERENCE] = destruct_reference_handler
     $handler_dict[CommandType::ARRAY_GET_ITEM] = array_get_item_handler
     $handler_dict[CommandType::ARRAY_GET_SIZE] = array_get_size_handler
     $handler_dict[CommandType::ARRAY_GET_RANK] = array_get_rank_handler
     $handler_dict[CommandType::ARRAY_SET_ITEM] = array_set_item_handler
     $handler_dict[CommandType::ARRAY] = array_handler
-
   end
 
 
