@@ -6,7 +6,7 @@ class Interpreter
   def execute(command, connection_type, tcp_address)
 
     command_serializer = CommandSerializer.new
-    message_byte_array = command_serializer.encode(command, connection_type, tcp_address)
+    message_byte_array = command_serializer.serialize(command, connection_type, tcp_address)
     if command.runtime_name == RuntimeName::RUBY
       require_relative '../receiver/receiver'
       response_byte_array = Receiver.new.send_command(message_byte_array, message_byte_array.length)
@@ -16,15 +16,15 @@ class Interpreter
     end
 
     command_deserializer = CommandDeserializer.new(response_byte_array,response_byte_array.length)
-    encoded_response = command_deserializer.decode
+    encoded_response = command_deserializer.deserialize
     return encoded_response
   end
 
   def process(byte_array, byte_array_len)
     command_deserializer = CommandDeserializer.new(byte_array,byte_array_len)
-    received_command = command_deserializer.decode
+    received_command = command_deserializer.deserialize
     handler = Handler.new
     command_serializer = CommandSerializer.new
-    return command_serializer.encode(handler.handle_command(received_command), 0, "0.0.0.0:0")
+    return command_serializer.serialize(handler.handle_command(received_command), 0, "0.0.0.0:0")
   end
 end
